==> kubernetes-model-apps-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/apps/DeploymentSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DeploymentSpecBuilder extends DeploymentSpecFluentImpl<DeploymentSpecBuilder> implements VisitableBuilder<DeploymentSpec,DeploymentSpecBuilder>{
  public DeploymentSpecBuilder() {
    this(false);
  }
  public DeploymentSpecBuilder(Boolean validationEnabled) {
    this(new DeploymentSpec(), validationEnabled);
  }
  public DeploymentSpecBuilder(DeploymentSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public DeploymentSpecBuilder(DeploymentSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DeploymentSpec(), validationEnabled);
  }
  public DeploymentSpecBuilder(DeploymentSpecFluent<?> fluent,DeploymentSpec instance) {
    this(fluent, instance, false);
  }
  public DeploymentSpecBuilder(DeploymentSpecFluent<?> fluent,DeploymentSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withMinReadySeconds(instance.getMinReadySeconds());
      fluent.withPaused(instance.getPaused());
      fluent.withProgressDeadlineSeconds(instance.getProgressDeadlineSeconds());
      fluent.withReplicas(instance.getReplicas());
      fluent.withRevisionHistoryLimit(instance.getRevisionHistoryLimit());
      fluent.withSelector(instance.getSelector());
      fluent.withStrategy(instance.getStrategy());
      fluent.withTemplate(instance.getTemplate());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public DeploymentSpecBuilder(DeploymentSpec instance) {
    this(instance,false);
  }
  public DeploymentSpecBuilder(DeploymentSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withMinReadySeconds(instance.getMinReadySeconds());
      this.withPaused(instance.getPaused());
      this.withProgressDeadlineSeconds(instance.getProgressDeadlineSeconds());
      this.withReplicas(instance.getReplicas());
      this.withRevisionHistoryLimit(instance.getRevisionHistoryLimit());
      this.withSelector(instance.getSelector());
      this.withStrategy(instance.getStrategy());
      this.withTemplate(instance.getTemplate());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  DeploymentSpecFluent<?> fluent;
  Boolean validationEnabled;
  public DeploymentSpec build() {
    DeploymentSpec buildable = new DeploymentSpec(fluent.getMinReadySeconds(),fluent.getPaused(),fluent.getProgressDeadlineSeconds(),fluent.getReplicas(),fluent.getRevisionHistoryLimit(),fluent.getSelector(),fluent.getStrategy(),fluent.getTemplate());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-apps-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/apps/DeploymentSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DeploymentSpecBuilder extends DeploymentSpecFluent<DeploymentSpecBuilder> implements VisitableBuilder<DeploymentSpec,DeploymentSpecBuilder>{
  public DeploymentSpecBuilder() {
    this(false);
  }
  public DeploymentSpecBuilder(Boolean validationEnabled) {
    this(new DeploymentSpec(), validationEnabled);
  }
  public DeploymentSpecBuilder(DeploymentSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public DeploymentSpecBuilder(DeploymentSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DeploymentSpec(), validationEnabled);
  }
  public DeploymentSpecBuilder(DeploymentSpecFluent<?> fluent,DeploymentSpec instance) {
    this(fluent, instance, false);
  }
  public DeploymentSpecBuilder(DeploymentSpecFluent<?> fluent,DeploymentSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new DeploymentSpec());

    if (instance != null) {
      fluent.withMinReadySeconds(instance.getMinReadySeconds());
      fluent.withPaused(instance.getPaused());
      fluent.withProgressDeadlineSeconds(instance.getProgressDeadlineSeconds());
      fluent.withReplicas(instance.getReplicas());
      fluent.withRevisionHistoryLimit(instance.getRevisionHistoryLimit());
      fluent.withSelector(instance.getSelector());
      fluent.withStrategy(instance.getStrategy());
      fluent.withTemplate(instance.getTemplate());
      fluent.withMinReadySeconds(instance.getMinReadySeconds());
      fluent.withPaused(instance.getPaused());
      fluent.withProgressDeadlineSeconds(instance.getProgressDeadlineSeconds());
      fluent.withReplicas(instance.getReplicas());
      fluent.withRevisionHistoryLimit(instance.getRevisionHistoryLimit());
      fluent.withSelector(instance.getSelector());
      fluent.withStrategy(instance.getStrategy());
      fluent.withTemplate(instance.getTemplate());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public DeploymentSpecBuilder(DeploymentSpec instance) {
    this(instance,false);
  }
  public DeploymentSpecBuilder(DeploymentSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new DeploymentSpec());

    if (instance != null) {
      this.withMinReadySeconds(instance.getMinReadySeconds());
      this.withPaused(instance.getPaused());
      this.withProgressDeadlineSeconds(instance.getProgressDeadlineSeconds());
      this.withReplicas(instance.getReplicas());
      this.withRevisionHistoryLimit(instance.getRevisionHistoryLimit());
      this.withSelector(instance.getSelector());
      this.withStrategy(instance.getStrategy());
      this.withTemplate(instance.getTemplate());
      this.withMinReadySeconds(instance.getMinReadySeconds());
      this.withPaused(instance.getPaused());
      this.withProgressDeadlineSeconds(instance.getProgressDeadlineSeconds());
      this.withReplicas(instance.getReplicas());
      this.withRevisionHistoryLimit(instance.getRevisionHistoryLimit());
      this.withSelector(instance.getSelector());
      this.withStrategy(instance.getStrategy());
      this.withTemplate(instance.getTemplate());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  DeploymentSpecFluent<?> fluent;
  Boolean validationEnabled;
  public DeploymentSpec build() {
    DeploymentSpec buildable = new DeploymentSpec(fluent.getMinReadySeconds(),fluent.getPaused(),fluent.getProgressDeadlineSeconds(),fluent.getReplicas(),fluent.getRevisionHistoryLimit(),fluent.buildSelector(),fluent.buildStrategy(),fluent.buildTemplate());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
